import httpRequest from '@/utils/axios'

// 上传文件
export function upload(data) {
  return httpRequest({
    url: '/api/alumni/v1/activities/tool/upload-file',
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data
  })
}

// 获取热门推荐列表
export function getHotList(params) {
  return httpRequest({
    url: '/api/alumni/v1/activities/hotest',
    method: 'get',
    params
  })
}

// 获取我参与的列表
export function getJoinList(params) {
  return httpRequest({
    url: '/api/alumni/v1/activities/my/participanted',
    method: 'get',
    params
  })
}

// 获取我发起的列表
export function getPublishList(params) {
  return httpRequest({
    url: '/api/alumni/v1/activities/my/initiated',
    method: 'get',
    params
  })
}

// 获取活动详情
export function getActivity(id) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}`,
    method: 'get'
  })
}

// 报名活动
export function joinActivity(data) {
  return httpRequest({
    url: '/api/alumni/v1/activities/join',
    method: 'post',
    data
  })
}

// 创建活动
export function createActivity(data) {
  return httpRequest({
    url: '/api/alumni/v1/activities/create',
    method: 'post',
    data
  })
}

// 修改活动
export function updateActivity(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}`,
    method: 'post',
    data
  })
}

// 删除活动
export function deleteActivity(id) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}`,
    method: 'delete'
  })
}

// 获取活动评论列表
export function getCommentList(id) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/replies`,
    method: 'get'
  })
}

// 添加评论
export function addComment(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/reply`,
    method: 'post',
    data
  })
}

// 添加回复
export function addCommentReplay(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/comment`,
    method: 'post',
    data
  })
}

// 点赞
export function addCommentLike(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/like`,
    method: 'post',
    data
  })
}

// 取消点赞
export function removeCommentLike(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/unlike`,
    method: 'post',
    data
  })
}

// 删除评论
export function deleteComment(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/reply/delete`,
    method: 'delete',
    data
  })
}

// 删除评论的回复
export function deleteCommentReply(id, data) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/comment/delete`,
    method: 'delete',
    data
  })
}

// 获取评论详情
export function getComment(id, params) {
  return httpRequest({
    url: `/api/alumni/v1/activities/${id}/reply/comments`,
    method: 'get',
    params
  })
}
